@@ -107,6 +107,9 @@ FAILEDOPERATION_DOMAINNOTBINDSERVICE = 'FailedOperation.DomainNotBindService'
 # 该域名未配置cname到默认域名，或者解析未生效。
 FAILEDOPERATION_DOMAINRESOLVEERROR = 'FailedOperation.DomainResolveError'
 
+# EIAM返回错误。
+FAILEDOPERATION_EIAMERROR = 'FailedOperation.EIAMError'
+
 # 事件总线绑定/解绑失败。
 FAILEDOPERATION_EBERROR = 'FailedOperation.EbError'
 
@@ -128,6 +131,9 @@ FAILEDOPERATION_ISDEFAULTMAPPING = 'FailedOperation.IsDefaultMapping'
 # 默认的二级域名输入错误。
 FAILEDOPERATION_NETSUBDOMAINERROR = 'FailedOperation.NetSubDomainError'
 
+# 操作后端通道失败。
+FAILEDOPERATION_OPERATEUPSTREAM = 'FailedOperation.OperateUpstream'
+
 # 设置路径映射错误。
 FAILEDOPERATION_PATHMAPPINGSETERROR = 'FailedOperation.PathMappingSetError'
 
@@ -164,6 +170,9 @@ INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 # CAuth内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
 
+# CLB内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
+INTERNALERROR_CLBEXCEPTION = 'InternalError.ClbException'
+
 # oss内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'
 
@@ -179,6 +188,12 @@ INTERNALERROR_VPCEXCEPTION = 'InternalError.VpcException'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 基础版服务不能绑定插件。
+INVALIDPARAMETER_BASICSERVICENOTALLOWATTACHPLUGIN = 'InvalidParameter.BasicServiceNotAllowAttachPlugin'
+
+# 当前绑定插件和已有插件冲突。
+INVALIDPARAMETER_DUPLICATEPLUGINCONFIG = 'InvalidParameter.DuplicatePluginConfig'
+
 # 参数格式错误。
 INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 
@@ -284,6 +299,9 @@ INVALIDPARAMETERVALUE_INVALIDUPSTREAM = 'InvalidParameterValue.InvalidUpstream'
 # URL参数错误。
 INVALIDPARAMETERVALUE_INVALIDURL = 'InvalidParameterValue.InvalidUrl'
 
+# 无效vpc信息。
+INVALIDPARAMETERVALUE_INVALIDVPCCONFIG = 'InvalidParameterValue.InvalidVpcConfig'
+
 # 方法错误。WEBSOCKET类型的后端服务，前端方法需要配置为GET。
 INVALIDPARAMETERVALUE_INVALIDWSMETHOD = 'InvalidParameterValue.InvalidWSMethod'
 
@@ -314,6 +332,9 @@ LIMITEXCEEDED = 'LimitExceeded'
 # API文档数量超出限制。
 LIMITEXCEEDED_APIDOCLIMITEXCEEDED = 'LimitExceeded.APIDocLimitExceeded'
 
+# 访问密钥数量超出限制。
+LIMITEXCEEDED_ACCESSKEYCOUNTINUSAGEPLANLIMITEXCEEDED = 'LimitExceeded.AccessKeyCountInUsagePlanLimitExceeded'
+
 # 服务绑定的应用数量超过限制。
 LIMITEXCEEDED_APIAPPCOUNTLIMITEXCEEDED = 'LimitExceeded.ApiAppCountLimitExceeded'
 
@@ -422,6 +443,12 @@ UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsa
 # 当前插件不支持绑定。
 UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
 
+# 基础版服务不能创建超过一个API。
+UNSUPPORTEDOPERATION_BASICSERVICENOMOREAPI = 'UnsupportedOperation.BasicServiceNoMoreApi'
+
+# 日志检索起始时间间隔。
+UNSUPPORTEDOPERATION_CLSSEARCHTIME = 'UnsupportedOperation.ClsSearchTime'
+
 # 协议为HTTP时，不支持强制Https。
 UNSUPPORTEDOPERATION_FORCEHTTPS = 'UnsupportedOperation.ForceHttps'
 
@@ -479,6 +506,9 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEAPI = 'UnsupportedOperation.UnsupportedDel
 # 服务使用中，不能被删除。
 UNSUPPORTEDOPERATION_UNSUPPORTEDDELETESERVICE = 'UnsupportedOperation.UnsupportedDeleteService'
 
+# 当前VPC通道存在绑定关系，不支持当前操作。
+UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEUPSTREAM = 'UnsupportedOperation.UnsupportedDeleteUpstream'
+
 # 不支持网络类型。
 UNSUPPORTEDOPERATION_UNSUPPORTEDNETTYPE = 'UnsupportedOperation.UnsupportedNetType'
 
